stm8dce.rel_parser API documentation
Description: This module provides functions to parse .rel and .lib files.

# Module `stm8dce.rel_parser`

This module provides functions to parse .rel and .lib files.

## Classes

`class RELParser`

  Class to parse .rel and .lib files.

  ## Attributes

  `modules` :`list`
    A list of Module objects parsed from the file.

  Initializes the RELParser with a file path and parses the file.

  ## Args

  `file_path` :`str`
    The path to the .rel or .lib file to be parsed.

  ### Methods

  `def __init__(self, file_path)`

    Initializes the RELParser with a file path and parses the file.

    ## Args

    `file_path` :`str`
      The path to the .rel or .lib file to be parsed.
  `def _parse(self, file_obj, file_path)`

    Parses the file and extracts modules and symbols.

    ## Args

    `file_obj` :`file object`
      The file object to parse.
    `file_path` :`str`
      The path to the .rel or .lib file to be parsed.